Index: c/src/libfs/src/imfs/imfs.h
===================================================================
--- c/src/libfs/src/imfs/imfs.h	(revision 562e7ed1ed282d9e6ecc50a228359bf35e5adec5)
+++ c/src/libfs/src/imfs/imfs.h	(revision df49c60c9671e4a28e636964d744c1f59fb6cb68)
@@ -158,7 +158,7 @@
   gid_t               st_gid;                /* Group ID of owner */
 
-  time_t              st_atime;              /* Time of last access */
-  time_t              st_mtime;              /* Time of last modification */
-  time_t              st_ctime;              /* Time of last status change */
+  time_t              stat_atime;            /* Time of last access */
+  time_t              stat_mtime;            /* Time of last modification */
+  time_t              stat_ctime;            /* Time of last status change */
   IMFS_jnode_types_t  type;                  /* Type of this entry */
   IMFS_types_union    info;
@@ -169,5 +169,5 @@
     struct timeval tv;                      \
     gettimeofday( &tv, 0 );                 \
-    _jnode->st_atime  = (time_t) tv.tv_sec; \
+    _jnode->stat_atime  = (time_t) tv.tv_sec; \
   } while (0)
                 
@@ -176,5 +176,5 @@
     struct timeval tv;                      \
     gettimeofday( &tv, 0 );                 \
-    _jnode->st_mtime  = (time_t) tv.tv_sec; \
+    _jnode->stat_mtime  = (time_t) tv.tv_sec; \
   } while (0)
                 
@@ -183,5 +183,5 @@
     struct timeval tv;                      \
     gettimeofday( &tv, 0 );                 \
-    _jnode->st_ctime  = (time_t) tv.tv_sec; \
+    _jnode->stat_ctime  = (time_t) tv.tv_sec; \
   } while (0)
 
@@ -190,6 +190,6 @@
     struct timeval tv;                      \
     gettimeofday( &tv, 0 );                 \
-    _jnode->st_mtime  = (time_t) tv.tv_sec; \
-    _jnode->st_atime  = (time_t) tv.tv_sec; \
+    _jnode->stat_mtime  = (time_t) tv.tv_sec; \
+    _jnode->stat_atime  = (time_t) tv.tv_sec; \
   } while (0)
 
Index: c/src/libfs/src/imfs/imfs_creat.c
===================================================================
--- c/src/libfs/src/imfs/imfs_creat.c	(revision 562e7ed1ed282d9e6ecc50a228359bf35e5adec5)
+++ c/src/libfs/src/imfs/imfs_creat.c	(revision df49c60c9671e4a28e636964d744c1f59fb6cb68)
@@ -73,7 +73,7 @@
   gettimeofday( &tv, 0 );
 
-  node->st_atime  = (time_t) tv.tv_sec;
-  node->st_mtime  = (time_t) tv.tv_sec;
-  node->st_ctime  = (time_t) tv.tv_sec;
+  node->stat_atime  = (time_t) tv.tv_sec;
+  node->stat_mtime  = (time_t) tv.tv_sec;
+  node->stat_ctime  = (time_t) tv.tv_sec;
 
   /*
Index: c/src/libfs/src/imfs/imfs_stat.c
===================================================================
--- c/src/libfs/src/imfs/imfs_stat.c	(revision 562e7ed1ed282d9e6ecc50a228359bf35e5adec5)
+++ c/src/libfs/src/imfs/imfs_stat.c	(revision df49c60c9671e4a28e636964d744c1f59fb6cb68)
@@ -51,7 +51,7 @@
   buf->st_gid   = the_jnode->st_gid;
 
-  buf->st_atime = the_jnode->st_atime;
-  buf->st_mtime = the_jnode->st_mtime;
-  buf->st_ctime = the_jnode->st_ctime;
+  buf->st_atime = the_jnode->stat_atime;
+  buf->st_mtime = the_jnode->stat_mtime;
+  buf->st_ctime = the_jnode->stat_ctime;
 
   return 0;
Index: c/src/libfs/src/imfs/imfs_utime.c
===================================================================
--- c/src/libfs/src/imfs/imfs_utime.c	(revision 562e7ed1ed282d9e6ecc50a228359bf35e5adec5)
+++ c/src/libfs/src/imfs/imfs_utime.c	(revision df49c60c9671e4a28e636964d744c1f59fb6cb68)
@@ -31,6 +31,6 @@
   the_jnode = (IMFS_jnode_t *) pathloc->node_access;
 
-  the_jnode->st_atime = actime;
-  the_jnode->st_mtime = modtime;
+  the_jnode->stat_atime = actime;
+  the_jnode->stat_mtime = modtime;
 
   return 0;

Index: c/src/libfs/src/imfs/imfs_directory.c
===================================================================
--- c/src/libfs/src/imfs/imfs_directory.c	(revision 562e7ed1ed282d9e6ecc50a228359bf35e5adec5)
+++ c/src/libfs/src/imfs/imfs_directory.c	(revision df49c60c9671e4a28e636964d744c1f59fb6cb68)
@@ -220,7 +220,7 @@
  *	st_blksize	0
  *   	st_blocks	0
  *	st_atime	time of last access
  *	st_mtime	time of last modification
  *	st_ctime	time of the last change
  *
  * This information will be returned to the calling function in a -stat- struct
@@ -249,7 +249,7 @@
    buf->st_blksize = 0;
    buf->st_blocks = 0;
-   buf->st_atime = the_jnode->st_atime;
-   buf->st_mtime = the_jnode->st_mtime;
-   buf->st_ctime = the_jnode->st_ctime;
+   buf->st_atime = the_jnode->stat_atime;
+   buf->st_mtime = the_jnode->stat_mtime;
+   buf->st_ctime = the_jnode->stat_ctime;
 
    buf->st_size = 0;
@@ -220,7 +220,7 @@
  *	st_blksize	0
  *   	st_blocks	0
- *	st_atime	time of last access
- *	st_mtime	time of last modification
- *	st_ctime	time of the last change
+ *	stat_atime	time of last access
+ *	stat_mtime	time of last modification
+ *	stat_ctime	time of the last change
  *
  * This information will be returned to the calling function in a -stat- struct